"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import UnrecognizedStr
from typing import Literal, Union


CardScheme = Union[
    Literal[
        "accel",
        "amex",
        "bancontact",
        "carte-bancaire",
        "cirrus",
        "culiance",
        "dankort",
        "diners-club",
        "discover",
        "eftpos-australia",
        "elo",
        "hipercard",
        "jcb",
        "maestro",
        "mastercard",
        "mir",
        "nyce",
        "other",
        "pulse",
        "rupay",
        "star",
        "uatp",
        "unionpay",
        "visa",
    ],
    UnrecognizedStr,
]
