"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from gr4vy.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional
from typing_extensions import Annotated, TypedDict


class TransactionRetriesReportSpecTypedDict(TypedDict):
    params: Dict[str, Any]
    r"""The parameters for the transaction retries report model."""
    model: Literal["transaction_retries"]
    r"""The report model type."""


class TransactionRetriesReportSpec(BaseModel):
    params: Dict[str, Any]
    r"""The parameters for the transaction retries report model."""

    MODEL: Annotated[
        Annotated[
            Optional[Literal["transaction_retries"]],
            AfterValidator(validate_const("transaction_retries")),
        ],
        pydantic.Field(alias="model"),
    ] = "transaction_retries"
    r"""The report model type."""
